(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/forms'], factory) :
	(factory((global['trumbowyg-ngx'] = {}),global.ng.core,global.ng.forms));
}(this, (function (exports,core,forms) { 'use strict';

var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @abstract
 */
var EditorBase = /** @class */ (function () {
    /**
     * @param {?} editorControl
     * @param {?} _config
     */
    function EditorBase(editorControl, _config) {
        this.editorControl = editorControl;
        this._config = _config;
        this.propagateChange = function (_) {
        };
        this.propagateTouched = function () {
        };
        editorControl.valueAccessor = this;
    }
    /**
     * @return {?}
     */
    EditorBase.prototype.ngOnInit = function () {
        var /** @type {?} */ control = this.editorControl.control;
        control.setValidators(control.validator);
        control.updateValueAndValidity();
    };
    /**
     * @return {?}
     */
    EditorBase.prototype.ngAfterViewInit = function () {
        var _this = this;
        $(this._editor.nativeElement).trumbowyg(Object.assign({}, this._config, this.options)).on('tbwinit', function () {
            $(_this._editor.nativeElement).trumbowyg(_this._disabled ? 'disable' : 'enable');
            _this.setContent(_this._initValue);
        }).on('tbwchange', function () {
            _this.propagateChange(_this.getContent());
        }).on('tbwblur', function () {
            _this.propagateTouched();
        });
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    EditorBase.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    EditorBase.prototype.registerOnTouched = function (fn) {
        this.propagateTouched = fn;
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EditorBase.prototype.writeValue = function (value) {
        this._initValue = value;
    };
    /**
     * @param {?} disabled
     * @return {?}
     */
    EditorBase.prototype.setDisabledState = function (disabled) {
        this._disabled = disabled;
    };
    /**
     * @return {?}
     */
    EditorBase.prototype.ngOnDestroy = function () {
        $(this._editor.nativeElement).trumbowyg('destroy');
    };
    /**
     * @param {?} content
     * @return {?}
     */
    EditorBase.prototype.setContent = function (content) {
        $(this._editor.nativeElement).trumbowyg('html', content);
    };
    /**
     * @return {?}
     */
    EditorBase.prototype.getContent = function () {
        return $(this._editor.nativeElement).trumbowyg('html');
    };
    return EditorBase;
}());
var TRUMBOWYG_OPTIONS = new core.InjectionToken('Trumbowyg options');
var EditorDirective = /** @class */ (function (_super) {
    __extends(EditorDirective, _super);
    /**
     * @param {?} editorControl
     * @param {?} _config
     * @param {?} _editor
     */
    function EditorDirective(editorControl, _config, _editor) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        _this._editor = _editor;
        return _this;
    }
    return EditorDirective;
}(EditorBase));
EditorDirective.decorators = [
    { type: core.Directive, args: [{
                selector: '[trumbowygNgxEditor]'
            },] },
];
/**
 * @nocollapse
 */
EditorDirective.ctorParameters = function () { return [
    { type: forms.NgControl, },
    { type: undefined, decorators: [{ type: core.Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: core.Optional },] },
    { type: core.ElementRef, },
]; };
EditorDirective.propDecorators = {
    'options': [{ type: core.Input },],
    'placeholder': [{ type: core.Input },],
};
var EditorComponent = /** @class */ (function (_super) {
    __extends(EditorComponent, _super);
    /**
     * @param {?} editorControl
     * @param {?} _config
     */
    function EditorComponent(editorControl, _config) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        return _this;
    }
    return EditorComponent;
}(EditorBase));
EditorComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'trumbowyg-ngx-editor',
                template: "\n      <textarea #editor [placeholder]=\"placeholder ? placeholder : ''\"></textarea>\n    ",
                styles: ["\n\n    "],
                changeDetection: core.ChangeDetectionStrategy.OnPush,
                encapsulation: core.ViewEncapsulation.None
            },] },
];
/**
 * @nocollapse
 */
EditorComponent.ctorParameters = function () { return [
    { type: forms.NgControl, },
    { type: undefined, decorators: [{ type: core.Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: core.Optional },] },
]; };
EditorComponent.propDecorators = {
    'options': [{ type: core.Input },],
    'placeholder': [{ type: core.Input },],
    '_editor': [{ type: core.ViewChild, args: ['editor',] },],
};
var TrumbowygNgxModule = /** @class */ (function () {
    function TrumbowygNgxModule() {
    }
    /**
     * @param {?} options
     * @return {?}
     */
    TrumbowygNgxModule.withConfig = function (options) {
        return {
            ngModule: TrumbowygNgxModule,
            providers: [
                { provide: TRUMBOWYG_OPTIONS, useValue: options }
            ]
        };
    };
    return TrumbowygNgxModule;
}());
TrumbowygNgxModule.decorators = [
    { type: core.NgModule, args: [{
                declarations: [
                    EditorComponent,
                    EditorDirective
                ],
                exports: [
                    EditorComponent,
                    EditorDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
TrumbowygNgxModule.ctorParameters = function () { return []; };

exports.TrumbowygNgxModule = TrumbowygNgxModule;
exports.ɵa = EditorComponent;
exports.ɵd = TRUMBOWYG_OPTIONS;
exports.ɵe = EditorDirective;
exports.ɵb = EditorBase;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=trumbowyg-ngx.umd.js.map
